************
Installation
************


Requirements
============

Astrocut has the following requirements:

- `Astropy`_ 
- `NumPy <http://www.numpy.org/>`_

  
Installing astrocut
===================

Using pip
---------

The easiest way to install Astrocut is using pip::

    pip install astrocut


From source
-----------

To install the bleading edge version from github without donloading,
run the following command::

  pip git+https://github.com/spacetelescope/astrocut.git

The latest development version of astrocut can be cloned from github
using this command::

    git clone https://github.com/spacetelescope/astrocut.git

To install astrocut (from the root of the source tree)::

    python setup.py install

   
